Enum webp::BitstreamFormat
source · [−]pub enum BitstreamFormat {
Undefined,
Lossy,
Lossless,
}Expand description
The format of the image bitstream which is either lossy, lossless or something else.
pub enum BitstreamFormat {
Undefined,
Lossy,
Lossless,
}The format of the image bitstream which is either lossy, lossless or something else.
UndefinedLossyLossless